#   pycsla-binary: Python implementation of CSLA .NET binary serialisation
#   Copyright (C) 2025  Lee Yingtong Li (RunasSudo)
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from dataclasses import dataclass, field
from typing import Any, List

@dataclass
class ChildData:
	# SerializationInfo.ChildData
	name: str
	is_dirty: bool
	reference_id: int

@dataclass
class FieldData:
	# SerializationInfo.FieldData
	name: str
	enum_type_name: str
	is_dirty: bool
	value: Any

@dataclass
class SerializationInfo:
	"""Format-agnostic representation of serialised CSLA object"""
	
	reference_id: int = 0
	type_name: str = ''
	children: List[ChildData] = field(default_factory=list)
	values: List[FieldData] = field(default_factory=list)
